# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Compute equilibrium value functions
#'
#' This function computes the equilibrium value functions
#' and the probabilities of entry and certain survival. Value
#' functions are computed via backward recursion. For this
#' function to work, the following \code{Settings} must have been
#' set:
#' \itemize{
#'  \item{\code{nCheck} The maximum number of firms with non-zero flow profits in some state of the world.}
#'  \item{\code{logGrid} The log of the grid}
#'  \item{\code{tolInner} The convergence tolerance for the inner loop}
#'  \item{\code{maxIterInner} The maximum number of iterations for the inner loop}
#' }
#' The following elements in \code{Param} must have been set
#' \itemize{
#'  \item{\code{k} A vector of length \code{nCheck} that determines the flow surplus}
#'  \item{\code{phi} A vector of length \code{nCheck} that governs the entry costs}
#'  \item{\code{omega} A scalar that governs the variance of the cost shocks}
#'  \item{\code{rho} The discount factor}
#'  \item{\code{Pi} A transition probability matrix for the demand grid, which is computed via
#'  \code{tauchen}}
#' }
#'
#' @param Settings is an R list of settings
#' @param Param is an R list of of parameters
#' @return List with value functions, entry probabilities and
#' certain survival probabilities.
valuefunction <- function(Settings, Param) {
    .Call('actyR_valuefunction', PACKAGE = 'actyR', Settings, Param)
}

#' Compute the mixing density
#'
#' This function computes the mixing density and returns it as a cube.
#'
#' @param Settings is an R list of settings
#' @param Param is an R list of of parameters
#' @param vS is a matrix with the value functions
#' @return A cube with the mixing density.
computeMixingDensity <- function(Settings, Param, vS) {
    .Call('actyR_computeMixingDensity', PACKAGE = 'actyR', Settings, Param, vS)
}

#' Compute likelihood contributions
#'
#' This function computes the vector of likelihood contributions for the
#' data set in \code{Data}. The likelihood contributions are computed as follows:
#' \itemize{
#' \item{ Use the function \code{valuefunction} to compute the equilibrium value functions
#' and the entry and sure survival probabilities}
#' \item{Compute the mixing density}
#' \item{Assemble the likelihood contributions for each observations}
#' }
#'
#' @param Settings is an R list of settings
#' @param Param is an R list of parameters
#' @param Data is an R list of the data and includes the matrices \code{N} and \code{C}
#' @return A column vector of likelihood contributions for each observation
likelihood <- function(Settings, Param, Data) {
    .Call('actyR_likelihood', PACKAGE = 'actyR', Settings, Param, Data)
}

#' Computes the model's transition matrix
#'
#' Computes the model's implied transition matrix
#' @param Settings is an R list with settings
#' @param Param is an R list with parameters
#' @return square matrix with cCheck * (nCheck + 1) rows and columns
getModelTransitionMatrix <- function(Settings, Param) {
    .Call('actyR_getModelTransitionMatrix', PACKAGE = 'actyR', Settings, Param)
}

#' Compute the gradient of the mixing density for a variable of interest
#'
#' This function computes the gradient of the mixing density. Note that all
#' parameters (except for omega) enter the mixing density only through the value functions. The
#' derivative of the value function is given as argument to the function.
#'
#' @param Settings is an R list of settings
#' @param Param is an R list of parameters
#' @param Eq is an R list of equilibrium objects
#' @param D_vS is a matrix of the gradient of the value function with respect to the variable of interest
#' @param OMEGA_FLAG is a flag whether the variable in question is omega or not
#' @return A cube of the mixing density \code{p^{ - 1}(a_S, c, n)}
mixingDensityGradient <- function(Settings, Param, Eq, D_vS, OMEGA_FLAG = FALSE) {
    .Call('actyR_mixingDensityGradient', PACKAGE = 'actyR', Settings, Param, Eq, D_vS, OMEGA_FLAG)
}

#' Compute the gradient of the likelihood function
#'
#' This function computes the gradient of the likelihood function.
#' It also computes the equilibrium and the likelihood function and
#' then returns a list with the likelihood and gradient contributions.
#'
#' @param Settings is an R list of settings
#' @param Param is an R list of parameters
#' @param Data an R list of the data with matrices \code{C} and \code{N}
#' @return An R list with a vector of likelihood contributions and a matrix of
#' gradient contributions.
likelihoodGradient <- function(Settings, Param, Data) {
    .Call('actyR_likelihoodGradient', PACKAGE = 'actyR', Settings, Param, Data)
}

#' Compute the gradient of the transition probability matrix with respect to mu
#'
#' @param Pi is the transition probability matrix
#' @param logGrid is the demand grid
#' @param mu is the mean of the innovations times 100
#' @param sigma is the standard deviation of the innovations times 100
#' @return A matrix with the derivative of the transition probability matrix with respect to mu.
dPidMu <- function(Pi, logGrid, mu, sigma) {
    .Call('actyR_dPidMu', PACKAGE = 'actyR', Pi, logGrid, mu, sigma)
}

#' Compute the gradient of the transition probability matrix with respect to sigma
#'
#' @param Pi is the transition probability matrix
#' @param logGrid is the demand grid
#' @param mu is the mean of the innovations
#' @param sigma is the standard deviation of the innovations times 100
#' @return A matrix with the derivative of the transition probability matrix with respect to sigma.
dPidSigma <- function(Pi, logGrid, mu, sigma) {
    .Call('actyR_dPidSigma', PACKAGE = 'actyR', Pi, logGrid, mu, sigma)
}

